pidgin: pigeon;gaim;chat;windows;live;aim
gnumeric: numeric;excel;table;chart;graph
basket: note;onenote;gtd;getting;things;done
gtg: gtd;getting;things;done
f-spot: fspot;gthumb;iphoto;picasa;photographs;edit;album;image
hedgewars: hedge;wars;war;hedgewar;worms;wormux;battle;fight
kino: home;imovie;pitivi;windows;maker
